@@ -16,7 +16,9 @@ class PublisherRegisterRequest(BaseModel):
     form_id: Optional[str] = None
     phone: Optional[str] = None
     aliases: Optional[Dict[str, str]] = None
+    phone_digital_code: Optional[str] = None
     passwordless: Optional[bool] = None
+    confirmed_email: Optional[bool] = None
     magic_link_sent: Optional[bool] = None
 
 
